@@ -8,6 +8,7 @@ from .types import (
     VaccinationByManufacturerRow,
     VaccinationDose,
     VaccinationByAgeRange,
+    VaccinationMunShare,
 )
 
 
@@ -15,6 +16,17 @@ def parse_date(raw):
     return datetime.datetime.utcfromtimestamp(float(raw) / 1000.0)
 
 
+def _parse_vaccinations_timestamp(data):
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        # ? raise exception or return error obj
+        return error
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+    return resp[0]["M0"]
+
+
 def _parse_vaccinations_by_day(data) -> "list[VaccinationByDayRow]":
     resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
     parsed_data = []
@@ -123,13 +135,13 @@ def _parse_vaccines_supplied_by_manufacturer(
     ]
     parsed_data = []
 
-    if len(manufacturers) > 3:
+    if len(manufacturers) > 4:
         print(manufacturers)
         raise Exception("New manufacturer!")
 
     def get_manufacturer(num):
-        manu_keys = ["pfizer", "moderna", "az"]
-        if num > 2 or num == None:
+        manu_keys = ["pfizer", "moderna", "az", "janssen"]
+        if num > 3 or num == None:
             print(num)
             raise Exception("Missing manufacturer!")
         return manu_keys[num]
@@ -149,7 +161,7 @@ def _parse_vaccines_supplied_by_manufacturer(
             raise Exception("Unknown R value!")
 
         manu_row = VaccinationByManufacturerRow(
-            date=None, pfizer=None, moderna=None, az=None
+            date=None, pfizer=None, moderna=None, az=None, janssen=None
         )
 
         if R == None:
@@ -197,6 +209,7 @@ def _parse_vaccines_supplied_by_manufacturer_cum(
         moderna = None
         pfizer = None
         az = None
+        janssen = None
 
         if len(elements) == 1:
             el = elements[0]
@@ -223,6 +236,7 @@ def _parse_vaccines_supplied_by_manufacturer_cum(
                 pfizer=pfizer,
                 moderna=moderna,
                 az=az,
+                janssen=janssen,
             )
         )
 
@@ -250,3 +264,99 @@ def _parse_vaccinations_by_age_range(data) -> "list[VaccinationDose]":
         parsed_data.append(VaccinationDose(date=date, dose=dose))
 
     return parsed_data
+
+
+# resp error example
+_resp_error = {
+    "DataShapes": [
+        {
+            "odata.error": {
+                "code": "InvalidOrMalformedSemanticQueryDefinition",
+                "source": "PowerBI",
+                "message": {
+                    "lang": "en-US",
+                    "value": "Encountered invalid QueryYearConstantExpression. Failed to parse type encoded string",
+                },
+                "azure:values": [
+                    {"timestamp": "2021-04-11T12:13:03.0228291Z"},
+                    {
+                        "additionalMessages": [
+                            {
+                                "Code": "InvalidOrMalformedSemanticQueryDefinition",
+                                "Severity": "Error",
+                                "Message": "Encountered invalid QueryYearConstantExpression. Failed to parse type encoded string",
+                            }
+                        ]
+                    },
+                ],
+            }
+        }
+    ]
+}
+
+# ? most likely we can refactor _parse_vaccinations_by_day
+def _parse_vaccinations_by_region_by_day(data):
+
+    if "DS" not in data["results"][0]["result"]["data"]["dsr"]:
+        error = data["results"][0]["result"]["data"]["dsr"]["DataShapes"][0][
+            "odata.error"
+        ]
+        # it happens when region name passed to _get_default_by_region_by_day_condition_values func is misspelled or not wrapped in single quotes
+        # ? raise exception or return error obj
+        return error
+
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+    parsed_data = []
+
+    r_list = [None, 1]
+
+    people_vaccinated = None
+    people_fully_vaccinated = None
+    for element in resp:
+        date = parse_date(element["G0"])
+
+        R = element["X"][0]["R"] if "R" in element["X"][0] else None
+
+        if R == None:
+            people_vaccinated = element["X"][0]["M0"]
+            people_fully_vaccinated = (
+                element["X"][1]["M0"] if len(element["X"]) > 1 else 0
+            )
+
+        if R == 1:
+            # as far as we know people_vaccinated same as previous
+            people_fully_vaccinated = (
+                element["X"][1]["M0"] if len(element["X"]) > 1 else 0
+            )
+
+        parsed_data.append(
+            VaccinationByDayRow(
+                date=date,
+                first_dose=people_vaccinated,
+                second_dose=people_fully_vaccinated,
+            )
+        )
+
+    return parsed_data
+
+
+def _parse_vaccinations_by_municipalities_share(data) -> "list[VaccinationMunShare]":
+    resp = data["results"][0]["result"]["data"]["dsr"]["DS"][0]["PH"][0]["DM0"]
+    parsed_data = []
+
+    for el in resp:
+        name, share2, share1, population = el["C"]
+        dose1 = round(int(population) * float(share1))
+        dose2 = round(int(population) * float(share2))
+        parsed_data.append(
+            VaccinationMunShare(
+                name=name,
+                dose1=dose1,
+                share1=float(share1),
+                dose2=dose2,
+                share2=float(share2),
+                population=population,
+            )
+        )
+
+    return parsed_data
