@@ -43,6 +43,7 @@ class VaccinationByManufacturerRow:
     pfizer: Optional[int]
     moderna: Optional[int]
     az: Optional[int]
+    janssen: Optional[int]
 
 
 @dataclass
@@ -55,3 +56,13 @@ class VaccinationDose:
 class VaccinationByAgeRange:
     dose1: "list[VaccinationDose]"
     dose2: "list[VaccinationDose]"
+
+
+@dataclass
+class VaccinationMunShare:
+    name: str
+    dose1: int
+    share1: float
+    dose2: int
+    share2: float
+    population: int
\ No newline at end of file
