@@ -116,11 +116,12 @@ class CepimoseTestCase(unittest.TestCase):
             self.assertEqual(row.pfizer, expected[0])
             self.assertEqual(row.moderna, expected[1])
             self.assertEqual(row.az, expected[2])
+            self.assertEqual(row.janssen, expected[3])
 
-        assertRow(data[1], datetime.datetime(2020, 12, 30), [8190, None, None])  # R = 2
-        assertRow(data[3], datetime.datetime(2021, 1, 11), [19890, None, None])  # R = 6
+        assertRow(data[1], datetime.datetime(2020, 12, 30), [8190, None, None, None])  # R = 2
+        assertRow(data[3], datetime.datetime(2021, 1, 11), [19890, None, None, None])  # R = 6
         assertRow(
-            data[16], datetime.datetime(2021, 2, 25), [None, 8400, 16800]
+            data[16], datetime.datetime(2021, 2, 25), [None, 8400, 16800, None]
         )  # combined: two response data items with same date; second has R = 1
 
         self.assertDatesIncreaseSince(data, datetime.datetime(2020, 12, 26))
@@ -134,11 +135,12 @@ class CepimoseTestCase(unittest.TestCase):
             self.assertEqual(row.pfizer, expected[0])
             self.assertEqual(row.moderna, expected[1])
             self.assertEqual(row.az, expected[2])
+            self.assertEqual(row.janssen, expected[3])
 
-        assertRow(data[3], datetime.datetime(2021, 1, 11), [59670, None, None])
-        assertRow(data[7], datetime.datetime(2021, 1, 31), [None, 3600, None])
-        assertRow(data[10], datetime.datetime(2021, 2, 6), [None, None, 9600])
-        assertRow(data[16], datetime.datetime(2021, 2, 25), [None, 16800, 52800])
+        assertRow(data[3], datetime.datetime(2021, 1, 11), [59670, None, None, None])
+        assertRow(data[7], datetime.datetime(2021, 1, 31), [None, 3600, None, None])
+        assertRow(data[10], datetime.datetime(2021, 2, 6), [None, None, 9600, None])
+        assertRow(data[16], datetime.datetime(2021, 2, 25), [None, 16800, 52800, None])
         # assertRow(
         #     data[len(data) - 1], datetime.datetime(2021, 4, 2), [285480, 46800, 144000]
         # )  # this test will fail in the future
@@ -210,3 +212,59 @@ class CepimoseTestCase(unittest.TestCase):
 
         self.assertDatesIncreaseSince(data_dose1, datetime.datetime(2020, 12, 26))
         self.assertDatesIncreaseSince(data_dose2, datetime.datetime(2020, 12, 26))
+
+    def test_vaccinations_pomurska_by_day(self):
+        data = cepimose.vaccinations_pomurska_by_day()
+
+        self.assertGreater(len(data), 100)
+
+        def assertRow(row, expected_date, expected_first, expected_second):
+            self.assertEqual(row.date, expected_date)
+            self.assertAlmostEqual(row.first_dose, expected_first, delta=30)
+            self.assertAlmostEqual(row.second_dose, expected_second, delta=30)
+
+        assertRow(data[9], datetime.datetime(2021, 1, 5), 988, 0)
+        assertRow(data[22], datetime.datetime(2021, 1, 18), 2847, 5)
+
+        self.assertDatesIncreaseSince(data, datetime.datetime(2020, 12, 27))
+
+    def test_vaccinations_by_region_by_day(self):
+        data = cepimose.vaccinations_by_region_by_day()
+        expected_keys = [
+            "Goriška",
+            "Zasavska",
+            "Koroška",
+            "Gorenjska",
+            "Osrednjeslovenska",
+            "Posavska",
+            "Podravska",
+            "Pomurska",
+            "Savinjska",
+            "Jugovzhodna Slovenija",
+            "Primorsko-notranjska",
+            "Obalno-kraška",
+        ]
+
+        self.assertEquals(expected_keys, list(data.keys()), "Object keys")
+
+        for element in data.items():
+            print(element[0])
+            self.assertTrue(len(element[1]) != 0)
+            self.assertDatesIncreaseSince(element[1], datetime.datetime(2020, 12, 27))
+
+        pomurska_region = data["Pomurska"]
+
+        def assertRow(row, expected_date, expected_first, expected_second):
+            self.assertEqual(row.date, expected_date)
+            self.assertAlmostEqual(row.first_dose, expected_first, delta=30)
+            self.assertAlmostEqual(row.second_dose, expected_second, delta=30)
+
+        assertRow(pomurska_region[9], datetime.datetime(2021, 1, 5), 988, 0)
+        assertRow(pomurska_region[22], datetime.datetime(2021, 1, 18), 2847, 5)
+
+    def test_vaccinations_by_municipalities_share(self):
+        data = cepimose.vaccinations_by_municipalities_share()
+
+        mun_number = 212
+
+        self.assertTrue(len(data), mun_number)
\ No newline at end of file
